.. _onset:

Onset and Peak Detection With Two-Sided Line Models (TSLMs)
-----------------------------------------------------------
Examples published in "Onset Detection of Pulse-Shaped Bioelectrical Signals Using Linear State Space Models" [Waldmann2022]_.





